Linux Headquarters
[ Register ]
[ About us ] [ Home Page ]

Advertisement
[ Kernel ] [ Documentation ] [ Links ] [ Books ]

Advertisement

Kernel v2.4.16 /include/linux/sysctl.h

Filename:/include/linux/sysctl.h
Lines Added:3
Lines Deleted:1
Also changed in: (Previous) 2.4.16-pre1  2.4.15-greased-turkey  2.4.15-pre9  2.4.15-pre8  2.4.15-pre7  2.4.15-pre6 
(Following) 2.4.18-pre3-ac1  2.4.18-pre3-ac2  2.4.18-pre7-ac1  2.4.18-pre7-ac2  2.4.18-pre7-ac3  2.4.18-pre9-ac1 

Location
[  2.4.16
  [  include
    [  linux
       o  sysctl.h

Patch

diff -Nur linux-2.4.15/include/linux/sysctl.h linux/include/linux/sysctl.h
--- linux-2.4.15/include/linux/sysctl.h   Thu Nov 22 17:46:19 2001
+++ linux/include/linux/sysctl.h   Sat Nov 24 16:51:47 2001
@@ -139,7 +139,9 @@
    VM_PAGECACHE=7,      /* struct: Set cache memory thresholds */
    VM_PAGERDAEMON=8,   /* struct: Control kswapd behaviour */
    VM_PGT_CACHE=9,      /* struct: Set page table cache parameters */
-   VM_PAGE_CLUSTER=10   /* int: set number of pages to swap together */
+   VM_PAGE_CLUSTER=10,   /* int: set number of pages to swap together */
+       VM_MIN_READAHEAD=12,    /* Min file readahead */
+       VM_MAX_READAHEAD=13     /* Max file readahead */
 };
 
 


Comments: webmaster (at) linuxhq.com.
Advertising: banners (at) linuxhq.com.
Compilation ©1998-2008 Linux Headquarters, Inc.